
<!DOCTYPE html>
<html lang="en">

<head>
	<meta charset="utf-8">
	<title>Pricing Table</title>
	<meta name="viewport" content="width=device-width,initial-scale=1">
	<link rel="preconnect" href="https://fonts.googleapis.com">
	<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
	<link href="https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap" rel="stylesheet">
	<script src="https://cdn.tailwindcss.com"></script>
	<script defer src="https://cdn.jsdelivr.net/npm/alpinejs@3.x.x/dist/cdn.min.js"></script>
	<!-- https://cruip-tutorials.vercel.app/pricing-table -->
	<script>
		tailwind.config = {
			darkMode: 'class',
			theme: {
				extend: {
					fontFamily: {
						inter: ['Inter', 'sans-serif'],
					},
				},
			},
		};
	</script>
</head>

<body class="relative font-inter antialiased"

x-data="{
	monthSelected: {monthSelected},

	isLogedIn: {isLogedIn},
	isForCurrent: {isForCurrent},

	plan: '{plan}',
	interval: '{interval}',
	provider: '{provider}',

	isIos: {isIos},

	highlightPlan(thisPlan) {
		if (this.isForCurrent) {
			if ((this.monthSelected && this.interval == 'month') || (!this.monthSelected && this.interval == 'year')) {
				if (thisPlan == this.plan) {
					return 'dark'
				}
			}
		}

		return ''
	},

	actionHref(thisPlan) {
		return 'link:/' + thisPlan + '/' + (this.monthSelected ? 'month' : 'year')
	},

	actionText(thisPlan) {
		if (this.isForCurrent) {
			if ((this.monthSelected && this.interval == 'month') || (!this.monthSelected && this.interval == 'year')) {
				if (thisPlan == this.plan) {
					return 'Current Plan'
				}
			}

			return 'Change Plan'
		}

		return 'Purchase Plan'
	},

	actionClass(thisPlan) {
		if (this.isForCurrent) {
			if ((this.monthSelected && this.interval == 'month') || (!this.monthSelected && this.interval == 'year')) {
				if (thisPlan == this.plan) {
					return 'bg-lime-500 shadow-lime-950/10 hover:bg-lime-600 ocus-visible:ring-lime-300'
				}
			}

			return ''
		}

		return ''
	}
}"
>

	<main class="relative min-h-screen flex flex-col justify-center bg-slate-50 overflow-hidden">
		<div class="w-full max-w-6xl mx-auto px-4 md:px-2 py-3">
			<div class="text-slate-600 text-center text-sm mb-6">
				<template x-if="isForCurrent">
					<div>Current Plan: <span>{currentPlan}</span></div>
				</template>
				<template x-if="isLogedIn">
					<div>Account: <span>{displayUserId}</span></div>
				</template>
				<template x-if="!isLogedIn">
					<div>Please sign in to subscribe</div>
				</template>
				<div>{userEmail}</div>
			</div>

			<div class="text-xl text-center font-semibold mb-8">
				Pricing to suite all sizes of bussiness
			</div>

			<!-- Pricing table component -->
			<div>

				<!-- Pricing toggle -->
				<div class="flex justify-center max-w-[20rem] m-auto mb-8 lg:mb-8">
					<div class="relative flex w-full p-1 bg-white dark:bg-slate-900 rounded-full">
						<span class="absolute inset-0 m-1 pointer-events-none" aria-hidden="true">
							<span class="absolute inset-0 w-1/2 bg-indigo-500 rounded-full shadow-sm shadow-indigo-950/10 transform transition-transform duration-150 ease-in-out" :class="monthSelected ? 'translate-x-0' : 'translate-x-full'"></span>
						</span>
						<button class="relative flex-1 text-sm font-medium h-8 rounded-full focus-visible:outline-none focus-visible:ring focus-visible:ring-indigo-300 dark:focus-visible:ring-slate-600 transition-colors duration-150 ease-in-out" :class="monthSelected ? 'text-white' : 'text-slate-500 dark:text-slate-400'" @click="monthSelected = true" :aria-pressed="monthSelected">Monthly</button>
						<button class="relative flex-1 text-sm font-medium h-8 rounded-full focus-visible:outline-none focus-visible:ring focus-visible:ring-indigo-300 dark:focus-visible:ring-slate-600 transition-colors duration-150 ease-in-out" :class="monthSelected ? 'text-slate-500 dark:text-slate-400' : 'text-white'" @click="monthSelected = false" :aria-pressed="monthSelected">Yearly</button>
					</div>
				</div>

				<div class="max-w-sm mx-auto grid gap-6 lg:grid-cols-3 items-start lg:max-w-none">

					<!-- Pricing tab 3 -->
					<div class="h-full" :class="highlightPlan('premium')">
						<div class="relative flex flex-col h-full p-6 rounded-2xl bg-white dark:bg-slate-900 border border-slate-200 dark:border-slate-900 shadow shadow-slate-950/5">
							<div class="mb-5">
								<div class="text-slate-900 dark:text-slate-200 font-semibold mb-1">Premium</div>
								<div class="inline-flex items-baseline mb-2">
									<span class="text-slate-900 dark:text-slate-200 font-bold text-3xl">$</span>
									<span class="text-slate-900 dark:text-slate-200 font-bold text-4xl" x-text="monthSelected ? '12.99' : '129.99'"></span>
									<span class="text-slate-500 font-medium" x-text="monthSelected ? '/mo' : '/yr'"></span>
								</div>
								<div class="text-sm text-slate-500 mb-5">Unleash the full power with comprehensive solutions tailored for enterprises.</div>
								<a class="w-full inline-flex justify-center whitespace-nowrap rounded-lg bg-indigo-500 px-3.5 py-2.5 text-sm font-medium text-white shadow-sm shadow-indigo-950/10 hover:bg-indigo-600 focus-visible:outline-none focus-visible:ring focus-visible:ring-indigo-300 dark:focus-visible:ring-slate-600 transition-colors duration-150" :class="actionClass('premium')" :href="actionHref('premium')" x-text="actionText('premium')"></a>
							</div>
							<div class="text-slate-900 dark:text-slate-200 font-medium mb-3">Includes:</div>
							<ul class="text-slate-600 dark:text-slate-400 text-sm space-y-3 grow">
								<li class="flex items-center">
									<svg class="w-3 h-3 fill-emerald-500 mr-3 shrink-0" viewBox="0 0 12 12" xmlns="http://www.w3.org/2000/svg">
										<path d="M10.28 2.28L3.989 8.575 1.695 6.28A1 1 0 00.28 7.695l3 3a1 1 0 001.414 0l7-7A1 1 0 0010.28 2.28z" />
									</svg>
									<span>Invoices per month: Unlimited</span>
								</li>
								<li class="flex items-center">
									<svg class="w-3 h-3 fill-emerald-500 mr-3 shrink-0" viewBox="0 0 12 12" xmlns="http://www.w3.org/2000/svg">
										<path d="M10.28 2.28L3.989 8.575 1.695 6.28A1 1 0 00.28 7.695l3 3a1 1 0 001.414 0l7-7A1 1 0 0010.28 2.28z" />
									</svg>
									<span>Company: Unlimited</span>
								</li>
								<li class="flex items-center">
									<svg class="w-3 h-3 fill-emerald-500 mr-3 shrink-0" viewBox="0 0 12 12" xmlns="http://www.w3.org/2000/svg">
										<path d="M10.28 2.28L3.989 8.575 1.695 6.28A1 1 0 00.28 7.695l3 3a1 1 0 001.414 0l7-7A1 1 0 0010.28 2.28z" />
									</svg>
									<span>Platform: Web, iOS, Android</span>
								</li>
								<li class="flex items-center">
									<svg class="w-3 h-3 fill-emerald-500 mr-3 shrink-0" viewBox="0 0 12 12" xmlns="http://www.w3.org/2000/svg">
										<path d="M10.28 2.28L3.989 8.575 1.695 6.28A1 1 0 00.28 7.695l3 3a1 1 0 001.414 0l7-7A1 1 0 0010.28 2.28z" />
									</svg>
									Auto Data Sync
								</li>
							</ul>
						</div>
					</div>

				</div>

			</div>
			<!-- End: Pricing table component -->

		</div>
	</main>

	<!-- Page footer -->
	<footer>
		<div class="text-slate-600 dark:text-slate-400 text-xs space-y-3 ml-4 mr-4 mt-12 mb-5 leading-5 grow">
			Auto-renewable subscription:<br>
			• Payment will be charged to Account at confirmation of purchase<br>
			• Subscription automatically renews unless auto-renew is turned off at least 24-hours before the end of the current period<br>
			• Account will be charged for renewal within 24-hours prior to the end of the current period, and identify the cost of the renewal<br>
			• Subscriptions may be managed by the user and auto-renewal may be turned off by going to the user's Account Settings after purchase<br>
			• If you have purchased the plan at a promotional price, the promotional price will be applied instead of the current price<br>
			• The subscription is associated with the current Account only. If you need to subscribe for more accounts, please go to https://invoicemaster.io<br>
		</div>

		<template x-if="isIos">
			<div class="text-slate-600 dark:text-slate-400 text-xs space-y-3 ml-4 mr-4 mt-5 mb-8 leading-5 grow">
				All In One InApp purchase:<br>
				The All In One InApp purchase is discontinued. If you have already purchased the All In One please click <a href="link:/restore">Restore</a> to restore it. Please note, the All In One can be used for different accounts but can't be used on other platforms.
			</div>
		</template>

		<div class="text-center text-slate-600 dark:text-slate-400 text-xs space-y-3 mt-12 mb-28 leading-5">
			<a href="https://s3.amazonaws.com/www.finabase.io/privacy.html">Privacy Policy</a>
			|
			<a href="https://s3.amazonaws.com/www.finabase.io/terms.html">Terms of Use</a>
		</div>
	</footer>
</body>

</html>